import { csv } from 'd3';

const datasetURL =
  'https://gist.githubusercontent.com/SirishaManthena/143d8a4e801946f7437aec508d8f5254/raw/c138d08f102c2b8c7d61957ef9dba2d25e37cf42/nutritionalinfo.csv';

// Load the dataset
csv(datasetURL).then((data) => {
  // Extract menu items and nutritional values
  const menuItems = data.map((d) => d.Item);
  const carbohydrates = data.map((d) => +d.Carbohydrates);
  const protein = data.map((d) => +d.Protein);
  const totalFat = data.map((d) => +d['Total Fat']);

  // Create scatter plot for carbohydrates
  createScatterPlot(
    menuItems,
    carbohydrates,
    'Menu Items vs Carbohydrates',
    'Menu Items',
    'Carbohydrates',
    'carbs-scatter-plot',
  );

  // Create scatter plot for protein
  createScatterPlot(
    menuItems,
    protein,
    'Menu Items vs Protein',
    'Menu Items',
    'Protein',
    'protein-scatter-plot',
  );

  // Create scatter plot for total fat
  createScatterPlot(
    menuItems,
    totalFat,
    'Menu Items vs Total Fat',
    'Menu Items',
    'Total Fat',
    'fat-scatter-plot',
  );
});

function createScatterPlot(
  xData,
  yData,
  title,
  xAxisLabel,
  yAxisLabel,
  containerId,
) {
  const margin = {
    top: 50,
    right: 50,
    bottom: 50,
    left: 50,
  };
  const width = 700 - margin.left - margin.right;
  const height = 500 - margin.top - margin.bottom;

  const svg = d3
    .select(`#${containerId}`)
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  const xScale = d3
    .scaleBand()
    .domain(xData)
    .range([0, width])
    .padding(0.1);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(yData)])
    .range([height, 0]);

  const xAxis = d3.axisBottom(xScale);
  const yAxis = d3.axisLeft(yScale);

  svg
    .append('g')
    .attr('class', 'x axis')
    .attr('transform', `translate(0,${height})`)
    .call(xAxis)
    .selectAll('text')
    .style('text-anchor', 'end')
    .attr('dx', '-.8em')
    .attr('dy', '.15em')
    .attr('transform', 'rotate(-45)');

  svg.append('g').attr('class', 'y axis').call(yAxis);

  svg
    .append('text')
    .attr('class', 'x label')
    .attr('text-anchor', 'end')
    .attr('x', width)
    .attr('y', height + margin.top - 10)
    .text(xAxisLabel);

  svg
    .append('text')
    .attr('class', 'y label')
    .attr('text-anchor', 'end')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 20)
    .attr('x', -margin.top)
    .text(yAxisLabel);

  svg
    .append('text')
    .attr('class', 'title')
    .attr('text-anchor', 'middle')
    .attr('x', width / 2)
    .attr('y', -margin.top / 2)
    .text(title);

  svg
    .selectAll('.dot')
    .data(yData)
    .enter()
    .append('circle')
    .attr('class', 'dot')
    .attr(
      'cx',
      (d, i) => xScale(xData[i]) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d))
    .attr('r', 5)
    .style('fill', 'steelblue');
}
